'use strict';

var fs = require('fs');
var crypto = require('crypto');
var path = require('path');

var createHash = function(file, len){
    return crypto.createHash('md5').update(file).digest('hex').substr(0, len);
}

var RESOURCE = {
    'LOAD':/(load\()['"]([^'"]+)['"]/g,
    'JS': /(<script[^>]+src=)['"]([^'"]+)["']/ig,
    'CSS': /(<link[^>]+href=)['"]([^'"]+)["']/ig,
    'IMG': /(<img[^>]+src=)['"]([^'"]+)["']/ig,
    'URL': /(url\s*[\(=])(?!data:|about:)([^)]*)/ig
}

var rev = function(content, dirname, options, matchRegExp){
    var Module = this;
    var Regs = matchRegExp || RESOURCE;
    for(var type in Regs){
        content = content.replace(Regs[type], function(str, tag, src){
            if(/^https?:\/\//.test(src)){
                return str;
            }
            var url = src = src.replace(/(^['"]|['"]$)/g, '').replace(/(\?|\#)[\s\S]*$/g, '');
            if(type === 'LOAD'){
                src = Module.setId(src, dirname)[0];
                if(!/\.js$/.test(src)){
                    src += '.js';
                }
            }
            //没有文件类型
            else if(!/\.[^\.]+$/.test(src)){
                return str;
            }
            else{
                //检测是否为相对路径
                if(/^(\w|\.)/.test(src)){
                    //本地路径
                    if(/^file:/.test(src)){
                        src = src.replace(/^file:\/+/, '')
                    }
                    else{
                        src = path.join(dirname, src);
                    }
                }
                else if(typeof options.filterPath === 'function'){
                    src = options.filterPath(src, dirname)
                }
            }

            if(!src){
                return str
            }
            src = path.normalize(src);
            if(fs.existsSync(src)){
                var buffer = fs.readFileSync(src);
                //修改样式表里的资源版本号
                if(/\.css$/.test(src)){
                    var csscon = buffer.toString();
                    var csspath = path.dirname(src);
                    var newcon = rev(csscon, csspath, options, {
                        'URL':RESOURCE.URL
                    })
                    fs.writeFileSync(src, newcon);
                    buffer = fs.readFileSync(src)
                }
                var md5 = createHash(buffer, options.hashlen || 7);
                var hash = '';
                var ext = path.extname(src);
                if(ext === '.eot'){
                    hash = '#iefix';
                }
                else if(ext === '.svg'){
                    hash = '#iconfont';
                }
                src = url + '?v='+md5+hash
            }
            else{
                return str
            }
            return tag + '"' + src + '"';
        });
    }
    return content
}

module.exports = function(){
    return rev.apply(this, arguments)
}
